part of '../fourpaypayments.dart';

class _FlutterApplePay {
  static const MethodChannel _channel =
      const MethodChannel('flutter_apple_pay');

  static Future<dynamic> getPaymentToken({
    @required String countryCode,
    @required String currencyCode,
    @required List<_ApplePayPaymentNetwork> paymentNetworks,
    @required String merchantIdentifier,
    bool isPending = false,
    @required List<_ApplePayPaymentItem> paymentItems,
  }) async {
    assert(countryCode != null);
    assert(currencyCode != null);
    assert(paymentItems != null);
    assert(merchantIdentifier != null);
    assert(paymentItems != null);

    final Map<String, Object> args = <String, dynamic>{
      'paymentNetworks':
          paymentNetworks.map((item) => item.toString().split('.')[1]).toList(),
      'countryCode': countryCode,
      'currencyCode': currencyCode,
      'paymentItems':
          paymentItems.map((_ApplePayPaymentItem item) => item._toMap()).toList(),
      'merchantIdentifier': merchantIdentifier,
      'isPending': isPending
    };
    if (Platform.isIOS) {
      final dynamic paymenToken =
          await _channel.invokeMethod('getPaymentToken', args);
      return paymenToken;
    } else {
      throw Exception("Not supported operation system");
    }
  }

  static Future<void> closeApplePaySheet({@required bool isSuccess}) async {
    if (Platform.isIOS) {
      if (isSuccess) {
        await _channel.invokeMethod('closeApplePaySheetWithSuccess');
      } else {
        await _channel.invokeMethod('closeApplePaySheetWithError');
      }
    } else {
      throw Exception("Not supported operation system");
    }
  }

  static Future<bool> canMakePayments() async {
    if (Platform.isIOS) {
      return await _channel.invokeMethod('canMakePayments');
    } else {
      throw Exception("Not supported operation system");
    }
  }
}

class _ApplePayPaymentItem {
  final String label;
  final double amount;

  _ApplePayPaymentItem({@required this.label, @required this.amount}) {
    assert(this.label != null);
    assert(this.amount != null);
  }

  Map<String, dynamic> _toMap() {
    Map<String, dynamic> map = new Map();
    map["label"] = this.label;
    map["amount"] = this.amount;
    return map;
  }
}

enum _ApplePayPaymentNetwork {
  visa,
  mastercard,
  amex,
  quicPay,
  chinaUnionPay,
  discover,
  interac,
  privateLabel
}
